# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.custom_aggregation_spec_schema_aggregate_args_inner import CustomAggregationSpecSchemaAggregateArgsInner

class TestCustomAggregationSpecSchemaAggregateArgsInner(unittest.TestCase):
    """CustomAggregationSpecSchemaAggregateArgsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomAggregationSpecSchemaAggregateArgsInner:
        """Test CustomAggregationSpecSchemaAggregateArgsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomAggregationSpecSchemaAggregateArgsInner`
        """
        model = CustomAggregationSpecSchemaAggregateArgsInner()
        if include_optional:
            return CustomAggregationSpecSchemaAggregateArgsInner(
                parameter_key = '',
                friendly_name = '',
                description = '',
                parameter_type = 'column',
                model_problem_type = 'regression',
                parameter_dtype = 'undefined',
                tag_hints = [
                    'llm_context'
                    ],
                source_dataset_parameter_key = '',
                allowed_column_types = [
                    null
                    ],
                allow_any_column_type = True
            )
        else:
            return CustomAggregationSpecSchemaAggregateArgsInner(
                parameter_key = '',
                friendly_name = '',
                description = '',
                parameter_dtype = 'undefined',
                source_dataset_parameter_key = '',
        )
        """

    def testCustomAggregationSpecSchemaAggregateArgsInner(self):
        """Test CustomAggregationSpecSchemaAggregateArgsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
